==> chromium-74.0.3729.111.tar.xz: chromium-74.0.3729.111/chrome/browser/chromeos/accessibility/test_accessibility_focus_ring_controller.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/chromeos/accessibility/test_accessibility_focus_ring_controller.h"

#include <utility>

#include "ash/public/interfaces/constants.mojom.h"
#include "content/public/common/service_manager_connection.h"
#include "services/service_manager/public/cpp/connector.h"
#include "services/service_manager/public/cpp/service_filter.h"

TestAccessibilityFocusRingController::TestAccessibilityFocusRingController() {
  CHECK(content::ServiceManagerConnection::GetForProcess())
      << "ServiceManager is uninitialized. Did you forget to create a "
         "content::TestServiceManagerContext?";
  content::ServiceManagerConnection::GetForProcess()
      ->GetConnector()
      ->OverrideBinderForTesting(
          service_manager::ServiceFilter::ByName(ash::mojom::kServiceName),
          ash::mojom::AccessibilityFocusRingController::Name_,
          base::BindRepeating(&TestAccessibilityFocusRingController::Bind,
                              base::Unretained(this)));
}

TestAccessibilityFocusRingController::~TestAccessibilityFocusRingController() {
  content::ServiceManagerConnection::GetForProcess()
      ->GetConnector()
      ->ClearBinderOverrideForTesting(
          service_manager::ServiceFilter::ByName(ash::mojom::kServiceName),
          ash::mojom::AccessibilityFocusRingController::Name_);
}

void TestAccessibilityFocusRingController::SetFocusRingColor(
    uint32_t skcolor,
    const std::string& caller_id) {}

void TestAccessibilityFocusRingController::ResetFocusRingColor(
    const std::string& caller_id) {}

void TestAccessibilityFocusRingController::SetFocusRing(
    const std::vector<gfx::Rect>& rects_in_screen,
    ash::mojom::FocusRingBehavior focus_ring_behavior,
    const std::string& caller_id) {}

void TestAccessibilityFocusRingController::HideFocusRing(
    const std::string& caller_id) {}

void TestAccessibilityFocusRingController::SetHighlights(
    const std::vector<gfx::Rect>& rects_in_screen,
    uint32_t skcolor) {}

void TestAccessibilityFocusRingController::HideHighlights() {}

void TestAccessibilityFocusRingController::Bind(
    mojo::ScopedMessagePipeHandle handle) {
  binding_.Bind(
      ash::mojom::AccessibilityFocusRingControllerRequest(std::move(handle)));
}
void TestAccessibilityFocusRingController::EnableDoubleFocusRing(
    uint32_t skcolor,
    const std::string& caller_id) {}

void TestAccessibilityFocusRingController::DisableDoubleFocusRing(
    const std::string& caller_id) {}

==> chromium-75.0.3770.88.tar.xz: chromium-75.0.3770.88/chrome/browser/chromeos/accessibility/test_accessibility_focus_ring_controller.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/chromeos/accessibility/test_accessibility_focus_ring_controller.h"

#include <utility>

#include "ash/public/interfaces/constants.mojom.h"
#include "content/public/common/service_manager_connection.h"
#include "services/service_manager/public/cpp/connector.h"
#include "services/service_manager/public/cpp/service_filter.h"

TestAccessibilityFocusRingController::TestAccessibilityFocusRingController() {
  CHECK(content::ServiceManagerConnection::GetForProcess())
      << "ServiceManager is uninitialized. Did you forget to create a "
         "content::TestServiceManagerContext?";
  content::ServiceManagerConnection::GetForProcess()
      ->GetConnector()
      ->OverrideBinderForTesting(
          service_manager::ServiceFilter::ByName(ash::mojom::kServiceName),
          ash::mojom::AccessibilityFocusRingController::Name_,
          base::BindRepeating(&TestAccessibilityFocusRingController::Bind,
                              base::Unretained(this)));
}

TestAccessibilityFocusRingController::~TestAccessibilityFocusRingController() {
  content::ServiceManagerConnection::GetForProcess()
      ->GetConnector()
      ->ClearBinderOverrideForTesting(
          service_manager::ServiceFilter::ByName(ash::mojom::kServiceName),
          ash::mojom::AccessibilityFocusRingController::Name_);
}

void TestAccessibilityFocusRingController::SetFocusRing(
    const std::string& focus_ring_id,
    ash::mojom::FocusRingPtr focus_ring) {}

void TestAccessibilityFocusRingController::HideFocusRing(
    const std::string& focus_ring_id) {}

void TestAccessibilityFocusRingController::SetHighlights(
    const std::vector<gfx::Rect>& rects_in_screen,
    uint32_t skcolor) {}

void TestAccessibilityFocusRingController::HideHighlights() {}

void TestAccessibilityFocusRingController::Bind(
    mojo::ScopedMessagePipeHandle handle) {
  binding_.Bind(
      ash::mojom::AccessibilityFocusRingControllerRequest(std::move(handle)));
}
